Enum cafe::Button

source ·
#[repr(i32)]
pub enum Button {
Show 21 variants A, B, X, Y, Back, Guide, Start, LeftStick, RightStick, LeftShoulder, RightShoulder, DPadUp, DPadDown, DPadLeft, DPadRight, Misc1, Paddle1, Paddle2, Paddle3, Paddle4, Touchpad,
}

Variants



A



B



X



Y



Back



Guide



Start



LeftStick



RightStick



LeftShoulder



RightShoulder



DPadUp



DPadDown



DPadLeft



DPadRight



Misc1



Paddle1



Paddle2



Paddle3



Paddle4



Touchpad

Implementations

source

impl Button

source

pub fn from_string(button: &str) -> Option<Button>

Return the Button from a string description in the same format used by the game controller mapping strings.

source

pub fn string(self) -> String

Return a string for a given button in the same format using by the game controller mapping strings

source

pub fn from_ll(bitflags: SDL_GameControllerButton) -> Option<Button>

source

pub fn to_ll(self) -> SDL_GameControllerButton